@@ -111,6 +111,7 @@ class InputTargetHandler(object):
             target_padding=None,
             input_padding_value=0,
             target_padding_value=0,
+            stop_floating=False,
             float_cropping=None,           
             target_ratio=1,
             safe_rescale=True,
@@ -165,6 +166,7 @@ class InputTargetHandler(object):
             input_cropping,
             target_cropping,
             float_cropping,
+            stop_floating,
             size,
             width,
             height,
@@ -286,12 +288,14 @@ class InputTargetHandler(object):
             input_cropping,
             target_cropping,
             float_cropping,
+            stop_floating,
             size,
             width,
             height,
             example_path):
         self.target_ratio=target_ratio or 1
         self.input_cropping=input_cropping or cropping or 0
+        float_cropping=float_cropping or 0
         self.safe_rescale=safe_rescale
         if size:
             self.input_width=size
@@ -302,11 +306,17 @@ class InputTargetHandler(object):
         self._ensure_dimensions(example_path)
         self.target_width=self._target_rescale(self.input_width)
         self.target_height=self._target_rescale(self.input_height)
+        if stop_floating:
+            self.input_cropping+=float_cropping
+            self.float_cropping=False
+        else:
+            self.float_cropping=float_cropping
         if self.input_cropping and (target_cropping=='auto'):
             self.target_cropping=self._target_rescale(self.input_cropping)
-        else:
+        elif isinstance(target_cropping,(int,float)):
             self.target_cropping=target_cropping
-        self.float_cropping=float_cropping
+        else:
+            self.target_cropping=None
 
 
     def _target_rescale(self,value):
